Class: CommandTower::Messaging::ChannelDeliveryExecutionJob
- Inherits:
-
ApplicationJob
- Object
- ActiveJob::Base
- ApplicationJob
- CommandTower::Messaging::ChannelDeliveryExecutionJob
- Defined in:
- app/jobs/command_tower/messaging/channel_delivery_execution_job.rb
Instance Method Summary collapse
-
#perform(channel_delivery_id) ⇒ Object
Execution::Recovery is the sole retry coordinator for execution failures.
Methods inherited from ApplicationJob
Instance Method Details
#perform(channel_delivery_id) ⇒ Object
Execution::Recovery is the sole retry coordinator for execution failures. Do not configure ActiveJob retry_on for placeholder/execution failures.
11 12 13 14 15 |
# File 'app/jobs/command_tower/messaging/channel_delivery_execution_job.rb', line 11 def perform(channel_delivery_id) CommandTower::Workflows::Messaging::Execution::DeliverWorkflow.call_from_job( channel_delivery_id:, ) end |