Class: CommandTower::Services::Auth::PasswordReset::Send

Inherits:
CommandTower::Services::ApplicationService show all
Defined in:
app/services/command_tower/services/auth/password_reset/send.rb

Overview

Issues a reset token and emails it. Callers always receive the same message so an unknown address cannot be distinguished from a known one.

Constant Summary collapse

SENT_MESSAGE =
"If an account exists with that email, a password reset link has been sent."

Constants inherited from CommandTower::ServiceBase

CommandTower::ServiceBase::ON_ARGUMENT_VALIDATION

Instance Method Summary collapse

Methods inherited from CommandTower::Services::ApplicationService

call, inherited

Methods included from Transactional

#fail_transaction!, #transaction

Methods inherited from CommandTower::ServiceBase

#command_tower_lifecycle, inherited, #internal_validate, #service_lifecycle_error_codes, #service_lifecycle_log_level, #validate!

Methods included from Logging::LifecycleDeclaration

included

Methods included from Execution::ContextAccess

#audit, #execution_context, #log_debug, #log_error, #log_info, #log_warn, #publish_event

Methods included from ArgumentValidation

included

Methods included from CommandTower::ServiceLogging

included

Instance Method Details

#callObject



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'app/services/command_tower/services/auth/password_reset/send.rb', line 14

def call
  malformed_email! unless email =~ URI::MailTo::EMAIL_REGEXP

  user = User.find_by(email: email.downcase.strip)
  context.message = SENT_MESSAGE

  if user.nil?
    log_info("Password reset requested for an email with no account")
    return
  end

  issued = issue_token(user)
  return if issued.nil?

  deliver(user, issued.secret)
end